==> fr-eficas-7.4.0.1_1.txz: usr/local/apps/eficas/Aster/prefs_ASTER.py <==
# -*- coding: utf-8 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2002  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
#
#
# ======================================================================

import os
import os.path as osp

# repIni sert a localiser le fichier editeur.ini
# Obligatoire
repIni = osp.dirname(osp.abspath(__file__))
rep_cata = osp.join(repIni, 'Cata')

# lang indique la langue utilisee pour les chaines d'aide : fr ou ang
lang = 'fr'

# Codage des strings qui accepte les accents (en remplacement de 'ascii')
encoding = 'utf-8'

# Pour eviter le message CATA
mode_nouv_commande = 'alpha'

# Utilisateur/Developpeur
isdeveloppeur = "NON"

# Plus utilisé à partir de 11.2, défini pour éviter des messages sur la console
rep_mat_STA10 = ''
rep_mat_115 = ''
rep_mat_stable = ''
rep_mat_121 = ''
rep_mat_testing = ''
#
path_doc = ''
rep_doc_STA10 = osp.join(repIni, 'Doc', 'clefs_docu_STA10')
rep_doc_stable = osp.join(repIni, 'Doc', 'clefs_docu_stable')
rep_doc_115 = rep_doc_stable
rep_doc_testing = osp.join(repIni, 'Doc', 'clefs_docu_testing')
rep_doc_121 = rep_doc_testing
exec_acrobat = "/usr/local/bin/firefox"

catalogues=(
    # on garde la ligne STA9 pour pouvoir l'utiliser si besoin
    #('ASTER', 'STA9',    osp.join(rep_cata, 'cata_v9'),  'python'),
    ('ASTER', 'STA10',   osp.join(rep_cata, 'cata_v10'), 'python'),
    ('ASTER', '11.5',    osp.join(rep_cata, 'cata_v11'), 'python', 'defaut'),
    ('ASTER', 'stable',  osp.join(rep_cata, 'cata_v11'), 'python', 'defaut'),
    ('ASTER', '12.1',    osp.join(rep_cata, 'cata_v12'), 'python'),
    ('ASTER', 'testing', osp.join(rep_cata, 'cata_v12'), 'python'),
)

def addCatalog(catalogName, catalogPath):
    """
    This function helps you to add a new catalog dynamically
    """
    global catalogues
    item = ('ASTER', catalogName, catalogPath, 'python')
    catalogues += (item, )

==> fr-eficas-7.5.0.1.txz: usr/local/apps/eficas/Aster/prefs_ASTER.py <==
# -*- coding: utf-8 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2002  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

import os
import os.path as osp

# repIni sert a localiser le fichier editeur.ini
# Obligatoire
repIni = osp.dirname(osp.abspath(__file__))

rep_stable = os.environ.get("ASTER_STABLE", "")
rep_testing = os.environ.get("ASTER_TESTING", "")

# lang indique la langue utilisee pour les chaines d'aide : fr ou ang
lang = 'fr'

# Codage des strings qui accepte les accents (en remplacement de 'ascii')
encoding = 'utf-8'

# Pour eviter le message CATA
mode_nouv_commande = 'alpha'

# Utilisateur/Developpeur
isdeveloppeur = "NON"

# Plus utilisé à partir de 11.2, défini pour éviter des messages sur la console
rep_mat_117 = ''
rep_mat_stable = ''
rep_mat_123 = ''
rep_mat_testing = ''

path_doc = ''
rep_doc_stable = osp.join(repIni, 'Doc', 'clefs_docu_stable')
rep_doc_117 = rep_doc_stable
rep_doc_testing = osp.join(repIni, 'Doc', 'clefs_docu_testing')
rep_doc_123 = rep_doc_testing
exec_acrobat = "/usr/local/bin/firefox"

catalogues=(
    # ('ASTER', '11.7',    osp.join(rep_stable,  'lib/aster/Cata/cata.py'), 'python', 'defaut'),
    # ('ASTER', 'stable',  osp.join(rep_stable,  'lib/aster/Cata/cata.py'), 'python', 'defaut'),
    # ('ASTER', '12.3',    osp.join(rep_testing, 'lib/aster/Cata/cata.py'), 'python'),
    # ('ASTER', 'testing', osp.join(rep_testing, 'lib/aster/Cata/cata.py'), 'python'),
#CATALOG_MARKER
)

def addCatalog(catalogName, catalogPath):
    """
    This function helps you to add a new catalog dynamically
    """
    global catalogues
    item = ('ASTER', catalogName, catalogPath, 'python')
    catalogues += (item, )
